@@ -409,6 +409,8 @@ def interactive_select():
 
     # 准备选择列表
     choices = []
+    current_choice = None  # 保存当前激活配置的Choice对象
+    
     for name, config in configs.items():
         display = format_config_display(name, config)
         prefix = "→ " if name == current else "  "
@@ -417,10 +419,16 @@ def interactive_select():
             choice_text = f"✅ {display}"  # 使用勾号代替箭头，更清晰
         else:
             choice_text = f"  {display}"
-        choices.append(questionary.Choice(
+        
+        choice = questionary.Choice(
             choice_text,
             value=name
-        ))
+        )
+        choices.append(choice)
+        
+        # 保存当前激活配置的Choice对象
+        if name == current:
+            current_choice = choice
 
     # 使用箭头键选择
     click.echo("\n使用↑↓箭头键浏览，回车键确认选择，ESC键退出")
@@ -428,7 +436,7 @@ def interactive_select():
     selected = _safe_questionary_select(
         "选择配置:",
         choices=choices,
-        default=current
+        default=current_choice  # 使用Choice对象而不是字符串
     )
 
     if not selected:
@@ -552,7 +560,11 @@ def _safe_questionary_select(message: str, choices: List[questionary.Choice],
             message,
             choices=choices,
             default=default,
-            style=style or _get_questionary_style()
+            style=style or _get_questionary_style(),
+            # 优化参数提高兼容性和可靠性
+            use_shortcuts=False,    # 禁用快捷键避免冲突
+            use_indicator=True,     # 显示指示器
+            show_selected=True      # 显示选中状态
         ).ask()
 
         # questionary 在ESC时可能返回None或空字符串
