@@ -1,5 +1,6 @@
 import json
 import os
+import subprocess
 from pathlib import Path
 from typing import Dict, Any, List, Optional
 from json_repair import repair_json
@@ -57,36 +58,36 @@ class ConfigManager:
     def _handle_json_error(self, error: json.JSONDecodeError) -> Dict[str, Any]:
         """处理JSON格式错误，尝试修复配置文件"""
         import shutil
-        
+
         # 备份原始损坏文件
         backup_file = self.config_file.with_suffix('.json.backup')
         shutil.copy2(self.config_file, backup_file)
-        
+
         try:
             # 读取文件内容
             with open(self.config_file, 'r', encoding='utf-8') as f:
                 content = f.read()
-            
+
             # 尝试修复JSON
             repaired_content = repair_json(content)
-            
+
             # 验证修复后的JSON是否有效
             try:
                 config = json.loads(repaired_content)
-                
+
                 # 保存修复后的配置
                 with open(self.config_file, 'w', encoding='utf-8') as f:
                     f.write(repaired_content)
                 os.chmod(self.config_file, 0o600)
-                
+
                 # 检查版本并迁移
                 if config.get('version') != '2.0':
                     config = self._migrate_config(config)
-                
+
                 print(f"✅ 配置文件JSON格式已自动修复")
                 print(f"📁 原始损坏文件已备份到: {backup_file}")
                 return config
-                
+
             except json.JSONDecodeError as repair_error:
                 # 修复失败，显示详细错误信息
                 error_msg = self._format_json_error_message(error, content)
@@ -96,26 +97,27 @@ class ConfigManager:
                 print(f"\n修复尝试失败:\n{repair_error}")
                 print(f"\n请手动修复配置文件或删除备份文件后重试")
                 raise SystemExit(1)
-                
+
         except Exception as repair_error:
             # 修复过程中出现其他错误
             print(f"❌ 尝试修复配置文件时发生错误: {repair_error}")
             print(f"📁 原始损坏文件已备份到: {backup_file}")
             print(f"\n请手动修复配置文件或删除备份文件后重试")
             raise SystemExit(1)
-    
+
     def _format_json_error_message(self, error: json.JSONDecodeError, content: str) -> str:
         """格式化JSON错误信息"""
         lines = content.splitlines()
-        error_line = lines[error.lineno - 1] if error.lineno <= len(lines) else ""
-        
+        error_line = lines[error.lineno -
+                           1] if error.lineno <= len(lines) else ""
+
         error_info = [
             f"错误位置: 第 {error.lineno} 行, 第 {error.colno} 列",
             f"错误类型: {error.msg}",
             f"错误行内容: {error_line}",
             f"错误位置标记: {' ' * (error.colno - 1)}^"
         ]
-        
+
         return "\n".join(error_info)
 
     def _migrate_config(self, old_config: Dict[str, Any]) -> Dict[str, Any]:
@@ -337,15 +339,48 @@ class ConfigManager:
         if index < 0 or index >= len(config["configs"][config_name][target_list]):
             return False
 
-        del config["configs"][config_name][target_list][index]
+        cfg = config["configs"][config_name]
+        active_attr = "active_key" if credential_type == "api_key" else "active_auth"
+        was_active = cfg[active_attr] == index
+
+        # 删除凭据
+        del cfg[target_list][index]
 
         # 调整激活索引
-        active_attr = "active_key" if credential_type == "api_key" else "active_auth"
-        if config["configs"][config_name][active_attr] >= len(config["configs"][config_name][target_list]):
-            config["configs"][config_name][active_attr] = max(
-                0, len(config["configs"][config_name][target_list]) - 1)
+        if was_active:
+            # 如果删除的是当前激活的凭据，需要重新选择激活凭据
+            if len(cfg[target_list]) > 0:
+                # If the current active index is still valid, keep it; otherwise, set to the last item
+                if cfg[active_attr] < len(cfg[target_list]):
+                    pass  # keep current active index
+                else:
+                    cfg[active_attr] = len(cfg[target_list]) - 1
+            else:
+                # 同类型没有凭据了，切换到其他类型
+                cfg[active_attr] = -1
+                # 优先激活 auth_tokens
+                if cfg["auth_tokens"]:
+                    cfg["active_auth"] = 0
+                    cfg["active_key"] = -1
+                elif cfg["api_keys"]:
+                    cfg["active_key"] = 0
+                    cfg["active_auth"] = -1
+                else:
+                    # 没有任何凭据，重置为无效状态
+                    cfg["active_key"] = -1
+                    cfg["active_auth"] = -1
+        elif cfg[active_attr] > index:
+            # 如果删除的凭据在当前激活凭据之前，需要调整索引
+            cfg[active_attr] -= 1
+        # 如果删除的凭据在当前激活凭据之后，索引不需要调整
+
+        # 最后检查索引是否仍然有效，防止意外情况
+        if cfg[active_attr] >= len(cfg[target_list]):
+            cfg[active_attr] = max(-1, len(cfg[target_list]) - 1)
 
         self._save_config(config)
+        print("✅ 配置项已移除！")
+        print("🔄 请在终端运行 'source ~/.claude-switch/cs-wrapper.sh' 命令来激活当前配置项.")
         return True
 
     def init_shell(self) -> str:
@@ -369,12 +404,12 @@ class ConfigManager:
             claude_switch_path = shutil.which('claude-switch')
             if claude_switch_path:
                 return claude_switch_path
-            
+
             # 优先查找 cs 命令
             cs_path = shutil.which('cs')
             if cs_path:
                 return cs_path
-                
+
             # 如果都找不到，返回 claude-switch 作为默认值
             return 'claude-switch'
 
@@ -458,7 +493,7 @@ fi
         try:
             # 检查当前是否可以找到命令
             cs_found = find_cs_command() != 'cs'
-            
+
             if shell_config.exists():
                 with open(shell_config, 'r') as f:
                     content = f.read()
@@ -466,38 +501,38 @@ fi
                     with open(shell_config, 'a') as f:
                         f.write(
                             f'\n# Claude Switch - 自动环境变量生效\n{source_line}\n')
-                    
+
                     success_msg = f"✅ 已添加配置到 {shell_config}"
                     if cs_found:
                         success_msg += f"\n✅ 检测到 claude-switch 命令: {cs_command}"
                     else:
                         success_msg += "\n⚠️  尚未检测到 claude-switch 命令，请确保已安装"
-                    
+
                     success_msg += f"\n📁 Shell 配置文件: {wrapper_file}"
                     success_msg += "\n🔄 请重启终端或运行: source ~/.claude-switch/cs-wrapper.sh"
                     success_msg += "\n\n🚀 快速开始:"
                     success_msg += "\n  cs add      # 添加配置"
                     success_msg += "\n  cs          # 选择配置"
                     success_msg += "\n  cs --help   # 查看帮助"
-                    
+
                     return success_msg
                 else:
                     return f"✅ Shell 集成已存在，配置文件: {wrapper_file}"
             else:
                 with open(shell_config, 'w') as f:
                     f.write(f'\n# Claude Switch - 自动环境变量生效\n{source_line}\n')
-                
+
                 success_msg = f"✅ 已创建配置文件 {shell_config}"
                 if cs_found:
                     success_msg += f"\n✅ 检测到 claude-switch 命令: {cs_command}"
                 else:
                     success_msg += "\n⚠️  尚未检测到 claude-switch 命令，请确保已安装"
-                
+
                 success_msg += f"\n📁 Shell 配置文件: {wrapper_file}"
                 success_msg += "\n🔄 请重启终端或运行: source ~/.claude-switch/cs-wrapper.sh"
-                
+
                 return success_msg
-                
+
         except Exception as e:
             return f"❌ 初始化失败: {e}\n💡 请检查文件权限或手动添加配置"
 
@@ -517,6 +552,10 @@ fi
                 f'export ANTHROPIC_AUTH_TOKEN="{credentials["auth_token"]}"\n')
             f.write(f'export ANTHROPIC_API_KEY="{credentials["api_key"]}"\n')
 
+        # 如果有 API Key，更新 .claude.json 中的 approved 列表
+        if credentials["api_key"]:
+            self.update_claude_json_approved(credentials["api_key"])
+
     def print_current_export(self) -> str:
         """打印当前配置的环境变量设置命令"""
         credentials = self.get_current_active_credentials()
@@ -534,10 +573,10 @@ fi
     def cleanup(self, verbose: bool = False) -> bool:
         """清理所有创建的文件和目录，用于卸载时使用"""
         import shutil
-        
+
         cleaned_files = []
         errors = []
-        
+
         # 1. 删除 ~/.claude-switch 目录及其所有内容
         if self.config_dir.exists():
             try:
@@ -549,33 +588,33 @@ fi
                 errors.append(f"删除配置目录失败: {e}")
                 if verbose:
                     print(f"❌ 删除配置目录失败: {self.config_dir} - {e}")
-        
+
         # 2. 清理 shell 配置文件中的相关配置
         shell_config_map = {
             'bash': Path.home() / '.bashrc',
             'zsh': Path.home() / '.zshrc',
             'fish': Path.home() / '.config' / 'fish' / 'config.fish'
         }
-        
+
         source_patterns = [
             f'source {self.config_dir / "cs-wrapper.sh"}',
             f'source {self.config_dir / "env.sh"}',
             '# Claude Switch',
             '# Claude Switch - 自动环境变量生效'
         ]
-        
+
         for shell_name, shell_config in shell_config_map.items():
             if shell_config.exists():
                 try:
                     with open(shell_config, 'r', encoding='utf-8') as f:
                         content = f.read()
-                    
+
                     original_content = content
-                    
+
                     # 删除包含我们的配置的行
                     lines = content.splitlines()
                     filtered_lines = []
-                    
+
                     for line in lines:
                         # 检查是否包含我们的配置标记
                         should_skip = False
@@ -583,10 +622,10 @@ fi
                             if pattern in line:
                                 should_skip = True
                                 break
-                        
+
                         if not should_skip:
                             filtered_lines.append(line)
-                    
+
                     # 如果内容有变化，则写入文件
                     new_content = '\n'.join(filtered_lines)
                     if new_content != original_content:
@@ -595,12 +634,12 @@ fi
                         cleaned_files.append(str(shell_config))
                         if verbose:
                             print(f"✅ 已清理 {shell_name} 配置: {shell_config}")
-                    
+
                 except Exception as e:
                     errors.append(f"清理 {shell_name} 配置失败: {e}")
                     if verbose:
                         print(f"❌ 清理 {shell_name} 配置失败: {shell_config} - {e}")
-        
+
         # 3. 清理环境变量（仅提示用户）
         if verbose:
             print("\n📝 提示：以下环境变量可能需要手动清理：")
@@ -608,7 +647,7 @@ fi
             print("   unset ANTHROPIC_AUTH_TOKEN")
             print("   unset ANTHROPIC_API_KEY")
             print("\n🔄 建议重启终端或重新加载 shell 配置使更改生效")
-        
+
         return len(errors) == 0
 
     def is_initialized(self) -> bool:
@@ -617,16 +656,16 @@ fi
         wrapper_file = self.config_dir / 'cs-wrapper.sh'
         if not wrapper_file.exists():
             return False
-        
+
         # 检查 shell 配置文件是否包含我们的配置
         shell_config_map = {
             'bash': Path.home() / '.bashrc',
             'zsh': Path.home() / '.zshrc',
             'fish': Path.home() / '.config' / 'fish' / 'config.fish'
         }
-        
+
         source_line = f'source {wrapper_file}'
-        
+
         for shell_config in shell_config_map.values():
             if shell_config.exists():
                 try:
@@ -636,7 +675,7 @@ fi
                         return True
                 except Exception:
                     continue
-        
+
         return False
 
     def is_wrapper_active(self) -> bool:
@@ -651,10 +690,87 @@ fi
         credentials = self.get_current_active_credentials()
         if not credentials:
             return ""
-        
+
         commands = [
             f'export ANTHROPIC_BASE_URL="{credentials["base_url"]}"',
             f'export ANTHROPIC_AUTH_TOKEN="{credentials["auth_token"]}"',
             f'export ANTHROPIC_API_KEY="{credentials["api_key"]}"'
         ]
         return '; '.join(commands)
+
+    def update_claude_json_approved(self, api_key: str) -> bool:
+        """更新 ~/.claude.json 文件中的 approved 列表，与 env-deploy.sh 脚本逻辑一致"""
+        claude_json_file = Path.home() / '.claude.json'
+
+        # 检查 jq 是否可用
+        if not self._is_jq_available():
+            print("⚠️  警告: jq 工具未安装，无法更新 .claude.json")
+            print("   请安装 jq: brew install jq (macOS) 或 sudo apt-get install jq (Linux)")
+            return False
+
+        # 提取 API 密钥的最后 20 个字符
+        if len(api_key) < 20:
+            key_suffix = api_key
+        else:
+            key_suffix = api_key[-20:]
+
+        # 创建 .claude.json 文件如果不存在
+        if not claude_json_file.exists():
+            try:
+                with open(claude_json_file, 'w') as f:
+                    json.dump({}, f, indent=2)
+                print(f"✅ 创建新的 .claude.json 文件")
+            except Exception as e:
+                print(f"❌ 创建 .claude.json 文件失败: {e}")
+                return False
+
+        # 使用 jq 更新 JSON 文件
+        jq_command = [
+            'jq',
+            '--arg', 'key', key_suffix,
+            '(. // {}) | .customApiKeyResponses.approved |= ([.[]?, $key] | unique)',
+            str(claude_json_file)
+        ]
+
+        try:
+            # 执行 jq 命令
+            result = subprocess.run(
+                jq_command,
+                capture_output=True,
+                text=True,
+                check=True
+            )
+
+            # 将结果写回文件
+            with open(claude_json_file, 'w') as f:
+                f.write(result.stdout)
+
+            # print(f"✅ 已更新 .claude.json 中的 approved 列表")
+
+            # 显示更新后的内容
+            # try:
+            #     with open(claude_json_file, 'r') as f:
+            #         claude_config = json.load(f)
+                # approved_list = claude_config.get('customApiKeyResponses', {}).get('approved', [])
+                # if approved_list:
+                #     print(f"📋 当前 approved 列表: {approved_list}")
+            # except Exception:
+            #     pass  # 不显示错误，避免干扰主要功能
+
+            return True
+
+        except subprocess.CalledProcessError as e:
+            print(f"❌ 更新 .claude.json 失败: {e}")
+            return False
+        except Exception as e:
+            print(f"❌ 更新 .claude.json 时发生错误: {e}")
+            return False
+
+    def _is_jq_available(self) -> bool:
+        """检查 jq 工具是否可用"""
+        try:
+            subprocess.run(['jq', '--version'],
+                           capture_output=True, check=True)
+            return True
+        except (subprocess.CalledProcessError, FileNotFoundError):
+            return False
